API Guide
Reservations
This guide serves as a reference for API endpoints of SAAM Property Management System. Adapt procedures based on your property's specific requirements and systems while maintaining the core steps for consistent service delivery.
If you have any questions that are beyond the scope of this help file, Please feel free to email via Support Center.
Getting New Reservations
To retrieve data for each reservation made at your property, you can use the following API endpoint. This guide will walk you through the process of sending a GET request and understanding the JSON response.
- To get new reservations, send a GET request to the following URL:
https://api.saampms.com/reservations/v1/new-reservations - You can use tools like Postman or cURL to make the request. Here’s an example using cURL:
curl -X GET "https://api.saampms.com/reservations/v1/new-reservations" \ -H "Authorization: Bearer YOUR_TOKEN" -
Upon a successful request, you will receive a JSON response containing details about the new reservations. Here’s an example of the response format:
{ "id": 4, "bookingno": "BDC-4848668357", "name": "John Doe", "check_in": "2025-05-12", "check_out": "2025-05-13", "nights": 1, "roomtype": "Deluxe Single Room", "person": "1", "price": 122.64, "rate": "Mobile(App) Rate", "source": "BookingCom", "payment": "property", "profile": null, "phone": null, "email": null }
Response Fields Explained
- id: Unique identifier for the reservation.
- bookingno: The booking number associated with the reservation.
- name: The name of the guest who made the reservation.
- check-in The date when the guest is scheduled to check in.
- check-out The date when the guest is scheduled to check out.
- nights: The total number of nights for the reservation.
- roomtype: The type of room booked.
- person: The number of guests for the reservation.
- price: The total price for the reservation.
- rate: The rate type for the booking (e.g., Mobile(App) Rate)..
- source: The platform through which the reservation was made (e.g., BookingCom)..
- payment: Indicates the payment method (e.g., property).
- profile: Guest profile information (if available)..
- phone: Guest phone number (if available).
- email: Guest email address (if available).
Guest Check-In
To get guest check-in information, send a GET request to the following URL:
https://api.saampms.com/reservations/v1/check-in
Example request
You can use tools like Postman or cURL to make the request. Here’s an example using cURL:
curl -X GET "https://api.saampms.com/reservations/v1/check-in" \
-H "Authorization: Bearer YOUR_TOKEN"
Understanding the JSON Response
Upon a successful request, you will receive a JSON response containing details about the guest check-ins. Here’s an example of the response format:
{
"id": 2,
"bookingno": "BDC-4797903651",
"name": "John Doe",
"check_in": "2025-05-13",
"check_out": "2025-05-16",
"nights": 3,
"roomtype": "Large Twin Room",
"person": "1",
"price": 135.38,
"rate": "Early booker rate plan (7+ days)",
"source": "BookingCom",
"payment": [],
"profile": null,
"phone": "+555 5555 5555",
"email": "[email protected]",
"roomno": 101
}
Response Fields Explained
- id: Unique identifier for the check-in record.
- bookingno: The booking number associated with the reservation.
- name: The name of the guest checking in.
- check_in: The date when the guest is scheduled to check in.
- check_out: The date when the guest is scheduled to check out.
- nights: The total number of nights for the stay.
- roomtype: The type of room booked.
- person: The number of guests for the reservation.
- price: The total price for the stay.
- rate: The rate type for the booking (e.g., Early booker rate plan).
- source: The platform through which the reservation was made (e.g., BookingCom).
- payment: Payment details (if available).
- profile: Guest profile information (if available).
- phone: Guest phone number.
- email: Guest email address.
- roomno: The room number assigned to the guest.
Billing
To retrieve information about each transaction made to your property, you can use the following API endpoint. This guide will help you understand how to send a GET or POST request and interpret the JSON response.
Get Income Transactions
To get income transaction information, send a GET request to the following URL:
https://api.saampms.com/income/v1/get-income
Example request
You can use tools like Postman or cURL to make the request. Here’s an example using cURL:
curl -X GET "https://api.saampms.com/income/v1/get-income" \
-H "Authorization: Bearer YOUR_TOKEN"
Understanding The JSON Response
Upon a successful request, you will receive a JSON response containing details about the income transactions. Here’s an example of the response format:
{
"id": 1,
"type": "Accommodation",
"amount": 50,
"currency": "USD",
"comment": null,
"method": "Cash",
"date": "2025-05-14T14:37:16.224339Z",
"guest": "John Doe"
}
Response Fields Exaplained
- id: Unique identifier for the income transaction.
- type: The type of income (e.g., Accommodation).
- amount: The amount of money received.
- currency: The currency in which the amount is denominated (e.g., USD).
- comment: Any additional comments related to the transaction (if available).
- method: The payment method used (e.g., Cash).
- date: The date and time when the transaction occurred.
- guest: The name of the guest associated with the transaction.
Finance
Get New Fixed Transactions
To retrieve information about new fixed expenses at your property, you can use the following API endpoint. This guide will help you understand how to send a GET request and interpret the JSON response. For a better understanding of what fixed expenses are, please refer to the Glossary
Sending GET Request
To get new fixed transaction information, send a GET request to the following URL:
https://api.saampms.com/finance/v1/get-fixed
Example Request
You can use tools like Postman or cURL to make the request. Here’s an example using cURL:
curl -X GET "https://api.saampms.com/finance/v1/get-fixed" \
-H "Authorization: Bearer YOUR_TOKEN"
Understanding The JSON Response
Upon a successful request, you will receive a JSON response containing details about the fixed transactions. Here’s an example of the response format:
{
"id": 1,
"name": "Rent",
"amount": 8000,
"currency": "USD",
"date": "2025-05-03",
"interval": "Month"
}
Response Fields Explained
- id: Unique identifier for the fixed transaction.
- name: The name of the fixed expense (e.g., Rent).
- amount: The amount of the fixed expense.
- currency: The currency in which the amount is denominated (e.g., USD).
- date: The date when the fixed expense is due.
- interval: The frequency of the fixed expense (e.g., Month).
Get Variable Transactions
To retrieve information about variable expenses at your property, you can use the following API endpoint. This guide will help you understand how to send a GET request and interpret the JSON response. For a better understanding of the concept of variable expenses, please refer to the Glossary
Sending a GET Request
To get variable transaction information, send a GET request to the following URL:
https://api.saampms.com/finance/v1/get-variable
Example Request
You can use tools like Postman or cURL to make the request. Here’s an example using cURL:
curl -X GET "https://api.saampms.com/finance/v1/get-variable" \
-H "Authorization: Bearer YOUR_TOKEN"
Understanding the JSON Response
Upon a successful request, you will receive a JSON response containing details about the variable transactions. Here’s an example of the response format:
{
"id": 1,
"name": "Booking.com commission",
"amount": 3600,
"currency": "USD",
"date": "2025-05-03",
"type": "OTA Comm."
}
Response Fields Explained
- id: Unique identifier for the variable transaction.
- name: The name of the variable expense (e.g., Booking.com commission).
- amount: The amount of the variable expense.
- currency: The currency in which the amount is denominated (e.g., USD).
- date: The date when the variable expense was incurred.
- type: The type of variable expense (e.g., OTA Comm.).
Inetgrations
SAAM PMS is fully integrated with Zapier, enabling you to connect your property management system with thousands of popular apps and automate workflows without any coding.
FAQ
A FAQ is a list of frequently asked questions (FAQs) and answers on a particular topic.
Support
If this documentation doesn't answer your questions, So, Please send us Email via Support Center
We are located in the GMT +2:00 time zone and answer every question within 3-5 business days (holiday seasons may take longer).